==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/jni/org_gnu_gdk_EventScroll.c <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

#include <jni.h>
#include <sys/types.h>
#include <gdk/gdk.h>
#include "gtk_java.h"

#ifdef __cplusplus
extern "C" 
{
#endif

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getWindow
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventScroll_getWindow (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return getGObjectHandle(env, (GObject *)obj_g->window);
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getSendEvent
 */
JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_EventScroll_getSendEvent (JNIEnv *env, jclass cls, 
    jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jboolean) obj_g->send_event;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getTime
 */
JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventScroll_getTime (JNIEnv *env, jclass cls, jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return obj_g->time;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getX
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getX (JNIEnv *env, jclass cls, jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->x;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getY
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getY (JNIEnv *env, jclass cls, jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->y;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getState
 */
JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventScroll_getState (JNIEnv *env, jclass cls, jobject obj)
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jint) obj_g->state;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getDirection
 */
JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventScroll_getDirection (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jint) obj_g->direction;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getDevice
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventScroll_getDevice (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return getGObjectHandle(env, obj_g->device);
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getXRoot
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getXRoot (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->x_root;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getYRoot
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getYRoot (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->y_root;
}


#ifdef __cplusplus
}

#endif

==> libgtk-java-2.8.1.tar.bz2: libgtk-java-2.8.1/src/jni/org_gnu_gdk_EventScroll.c <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

#include <jni.h>
#include <sys/types.h>
#include <gdk/gdk.h>
#include "gtk_java.h"

#ifdef __cplusplus
extern "C" 
{
#endif

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getWindow
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventScroll_getWindow (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return getGObjectHandle(env, (GObject *)obj_g->window);
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getSendEvent
 */
JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_EventScroll_getSendEvent (JNIEnv *env, jclass cls, 
    jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jboolean) obj_g->send_event;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getTime
 */
JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventScroll_getTime (JNIEnv *env, jclass cls, jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return obj_g->time;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getX
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getX (JNIEnv *env, jclass cls, jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->x;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getY
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getY (JNIEnv *env, jclass cls, jobject obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->y;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getState
 */
JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventScroll_getState (JNIEnv *env, jclass cls, jobject obj)
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jint) obj_g->state;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getDirection
 */
JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventScroll_getDirection (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jint) obj_g->direction;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getDevice
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventScroll_getDevice (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return getGObjectHandle(env, G_OBJECT(obj_g->device));
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getXRoot
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getXRoot (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->x_root;
}

/*
 * Class:     org.gnu.gdk.EventScroll
 * Method:    getYRoot
 */
JNIEXPORT jdouble JNICALL Java_org_gnu_gdk_EventScroll_getYRoot (JNIEnv *env, jclass cls, jobject 
    obj) 
{
    GdkEventScroll *obj_g = (GdkEventScroll *)getPointerFromHandle(env, obj);
    return (jdouble) obj_g->y_root;
}


#ifdef __cplusplus
}

#endif
